@@ -19,6 +19,7 @@
 
 import StringIO
 import os
+import sys
 import unittest
 import uuid
 
@@ -459,13 +460,27 @@ class ClientTestCase(unittest.TestCase):
         self.client.handle_VOLUME_DELETED(message)
 
 
-class CreateUDFTestCase(unittest.TestCase):
-    """Test cases for CreateUDF op."""
+class RequestTestCase(TwistedTestCase):
+
+    request_class = request.Request
 
     def setUp(self):
         """Initialize testing protocol."""
+        import types
+        self.request_class = types.ClassType(self.request_class.__name__,
+                                             (self.request_class,), {})
+
+
+class CreateUDFTestCase(RequestTestCase):
+    """Test cases for CreateUDF op."""
+
+    request_class = CreateUDF
+
+    def setUp(self):
+        """Initialize testing protocol."""
+        super(CreateUDFTestCase, self).setUp()
         self.protocol = FakedProtocol()
-        self.request = CreateUDF(self.protocol, path=PATH, name=NAME)
+        self.request = self.request_class(self.protocol, path=PATH, name=NAME)
         self.request.error = faked_error
         self.done_called = False
         self.request.done = was_called(self, 'done_called')
@@ -474,6 +489,7 @@ class CreateUDFTestCase(unittest.TestCase):
         """Clean up."""
         self.protocol = None
         self.request = None
+        super(CreateUDFTestCase, self).tearDown()
 
     def test_init(self):
         """Test request creation."""
@@ -511,13 +527,16 @@ class CreateUDFTestCase(unittest.TestCase):
         self.assertTrue(self.done_called, 'done() was called')
 
 
-class ListVolumesTestCase(unittest.TestCase):
+class ListVolumesTestCase(RequestTestCase):
     """Test cases for ListVolumes op."""
 
+    request_class = ListVolumes
+
     def setUp(self):
         """Initialize testing protocol."""
+        super(ListVolumesTestCase, self).setUp()
         self.protocol = FakedProtocol()
-        self.request = ListVolumes(self.protocol)
+        self.request = self.request_class(self.protocol)
         self.request.error = faked_error
         self.done_called = False
         self.request.done = was_called(self, 'done_called')
@@ -594,13 +613,16 @@ class ListVolumesTestCase(unittest.TestCase):
         self.assertEquals([], self.request.volumes)
 
 
-class DeleteVolumeTestCase(unittest.TestCase):
+class DeleteVolumeTestCase(RequestTestCase):
     """Test cases for DeleteVolume op."""
 
+    request_class = DeleteVolume
+
     def setUp(self):
         """Initialize testing protocol."""
+        super(DeleteVolumeTestCase, self).setUp()
         self.protocol = FakedProtocol()
-        self.request = DeleteVolume(self.protocol, volume_id=VOLUME)
+        self.request = self.request_class(self.protocol, volume_id=VOLUME)
         self.request.error = faked_error
         self.done_called = False
         self.request.done = was_called(self, 'done_called')
@@ -638,13 +660,16 @@ class DeleteVolumeTestCase(unittest.TestCase):
         self.assertTrue(self.done_called, 'done() was called')
 
 
-class GetDeltaTestCase(unittest.TestCase):
+class GetDeltaTestCase(RequestTestCase):
     """Test cases for GetDelta op."""
 
+    request_class = GetDelta
+
     def setUp(self):
         """Initialize testing protocol."""
+        super(GetDeltaTestCase, self).setUp()
         self.protocol = FakedProtocol()
-        self.request = GetDelta(self.protocol, SHARE, 0)
+        self.request = self.request_class(self.protocol, SHARE, 0)
         self.request.error = faked_error
         self.done_called = False
         self.request.done = was_called(self, 'done_called')
@@ -714,7 +739,8 @@ class GetDeltaTestCase(unittest.TestCase):
 
     def test_from_scratch_flag(self):
         """Test from scratch flag."""
-        self.request = GetDelta(self.protocol, SHARE, 0, from_scratch=True)
+        self.request = self.request_class(self.protocol, SHARE, 0,
+                                          from_scratch=True)
         self.request.done = was_called(self, 'done_called')
         self.request.start()
 
@@ -725,14 +751,15 @@ class GetDeltaTestCase(unittest.TestCase):
                           actual_msg.get_delta.share)
 
 
-class TestAuth(unittest.TestCase):
+class TestAuth(RequestTestCase):
     """Tests the authentication request."""
 
+    request_class = Authenticate
+
     def test_session_id(self):
         """Test that the request has the session id attribute."""
-
         SESSION_ID = "opaque_session_id"
-        req = Authenticate(FakedProtocol(), None)
+        req = self.request_class(FakedProtocol(), None)
         req.done = MethodMock()
         message = protocol_pb2.Message()
         message.type = protocol_pb2.Message.AUTH_AUTHENTICATED
@@ -741,14 +768,42 @@ class TestAuth(unittest.TestCase):
         self.assert_(req.done.called)
         self.assertEqual(req.session_id, SESSION_ID)
 
+    def test_with_metadata(self):
+        """Test with optional metadata."""
+        protocol = FakedProtocol()
+        protocol.dummy_authenticate('my_token',
+                                    metadata={'version': '0.1',
+                                              'platform': sys.platform})
+        msgs = protocol.messages
+        self.assertTrue(len(msgs), 1)
+        msg = msgs[0]
+        self.assertEqual(len(msg.auth_parameters), 1)
+        self.assertEqual(len(msg.metadata), 2)
+        metadata = {'version': '0.1', 'platform': sys.platform}
+        for md in msg.metadata:
+            self.assertTrue(md.key in metadata)
+            self.assertEqual(md.value, metadata[md.key])
 
-class TestGenerationInRequests(unittest.TestCase):
+    def test_without_metadata(self):
+        """Test without optional metadata."""
+        protocol = FakedProtocol()
+        protocol.dummy_authenticate('my_token')
+        msgs = protocol.messages
+        self.assertTrue(len(msgs), 1)
+        msg = msgs[0]
+        self.assertEqual(len(msg.auth_parameters), 1)
+        self.assertEqual(len(msg.metadata), 0)
+
+
+class TestGenerationInRequests(RequestTestCase):
     """Base class for testing that actions that change the volume will
     have a new_generation attribute set."""
 
+    request_class = MakeFile
+
     def build_request(self):
         """Creates the request object."""
-        return MakeFile(FakedProtocol(), None, None, "name")
+        return self.request_class(FakedProtocol(), None, None, "name")
 
     def build_message(self):
         """Creates the ending message for the request."""
@@ -770,9 +825,7 @@ class TestGenerationInRequests(unittest.TestCase):
 class TestGenerationInRequestsMakeDir(TestGenerationInRequests):
     """Tests for new_generation in MakeDir."""
 
-    def build_request(self):
-        """Creates the request object."""
-        return MakeDir(FakedProtocol(), None, None, "name")
+    request_class = MakeDir
 
     def build_message(self):
         """Creates the ending message for the request."""
@@ -785,9 +838,11 @@ class TestGenerationInRequestsMakeDir(TestGenerationInRequests):
 class TestGenerationInRequestsPutContent(TestGenerationInRequests):
     """Tests for new_generation in PutContent."""
 
+    request_class = PutContent
+
     def build_request(self):
         """Creates the request object."""
-        return PutContent(FakedProtocol(), None, None, None, None,
+        return self.request_class(FakedProtocol(), None, None, None, None,
                           None, None, None, None)
 
     def build_message(self):
@@ -801,22 +856,28 @@ class TestGenerationInRequestsPutContent(TestGenerationInRequests):
 class TestGenerationInRequestsUnlink(TestGenerationInRequestsPutContent):
     """Tests for new_generation in Unlink."""
 
+    request_class = Unlink
+
     def build_request(self):
         """Creates the request object."""
-        return Unlink(FakedProtocol(), None, None)
+        return self.request_class(FakedProtocol(), None, None)
 
 
 class TestGenerationInRequestsMove(TestGenerationInRequestsPutContent):
     """Tests for new_generation in Move."""
 
+    request_class = Move
+
     def build_request(self):
         """Creates the request object."""
-        return Move(FakedProtocol(), None, None, None, None)
+        return self.request_class(FakedProtocol(), None, None, None, None)
 
 
-class PutContentTestCase(TwistedTestCase):
+class PutContentTestCase(RequestTestCase):
     """Test cases for PutContent op."""
 
+    request_class = PutContent
+
     def test_max_payload_size(self):
         """Get the value from the protocol."""
         self.protocol = FakedProtocol()
@@ -829,7 +890,7 @@ class PutContentTestCase(TwistedTestCase):
     def test_bytesmessageproducer_maxpayloadsize(self):
         """The producer uses the payload size from the request."""
         # set up the PutContent
-        pc = PutContent(FakedProtocol(), None, None, None, None,
+        pc = self.request_class(FakedProtocol(), None, None, None, None,
                         None, None, None, None)
         assert 12345 != pc.max_payload_size
         pc.max_payload_size = 12345
