@@ -90,24 +90,26 @@ class StorageClient(request.RequestHandler):
 
         request.RequestHandler.dataReceived(self, data)
 
-    def dummy_authenticate(self, credentials):
+    def dummy_authenticate(self, credentials, metadata=None):
         """Authenticate to a server using the 'dummy auth' provider.
 
         Return a deferred that will get called with the request
         object when completed.
 
         """
-        p = Authenticate(self, {'dummy_token': credentials})
+        p = Authenticate(self, {'dummy_token': credentials},
+                         metadata=metadata)
         p.start()
         return p.deferred
 
-    def oauth_authenticate(self, consumer, token):
+    def oauth_authenticate(self, consumer, token, metadata=None):
         """Authenticate to a server using the OAuth provider.
 
         @param consumer: the OAuth consumer to authenticate with.
         @type consumer: `oauth.OAuthConsumer`
         @param token: a previously acquired OAuth access token.
         @type consumer: `oauth.OAuthToken`
+        @param kwargs: key/values to send as metadata
 
         Return a deferred that will get called with the request
         object when completed.
@@ -124,7 +126,7 @@ class StorageClient(request.RequestHandler):
         # Make sure all parameter values are strings.
         auth_parameters = dict(
             (key, str(value)) for key, value in req.parameters.iteritems())
-        p = Authenticate(self, auth_parameters)
+        p = Authenticate(self, auth_parameters, metadata=metadata)
         p.start()
         return p.deferred
 
@@ -571,6 +573,9 @@ class GetContent(request.Request):
 
     """
 
+    __slots__ = ('share', 'node_id', 'hash', 'offset', 'callback',
+                 'node_attr_callback', 'parts', 'data')
+
     def __init__(self, protocol, share, node_id, a_hash,
                  offset=0, callback=None, node_attr_callback=None):
         """Request the content of node with 'a_hash'.
@@ -651,6 +656,8 @@ class ListShares(request.Request):
 
     """
 
+    __slots__ = ('shares',)
+
     def _start(self):
         """Send the LIST_SHARES message to the server."""
         # pylint: disable=W0201
@@ -673,6 +680,8 @@ class ListShares(request.Request):
 class CreateShare(request.Request):
     """Create a share."""
 
+    __slots__ = ('node', 'share_to', 'name', 'access_level', 'share_id')
+
     # these are the valid access levels and their translation to the
     # protocol message
     _valid_access_levels = {
@@ -730,6 +739,8 @@ class CreateShare(request.Request):
 class AcceptShare(request.Request):
     """Accept a share (or not)."""
 
+    __slots__ = ('share_id', 'answer')
+
     # these are the valid answers and their translation to the
     # protocol message
     _valid_answer = {
@@ -775,6 +786,8 @@ class AcceptShare(request.Request):
 class DeleteShare(request.Request):
     """Delete a share."""
 
+    __slots__ = ('share_id',)
+
     def __init__(self, protocol, share_id):
         """Delete a share we had offered to someone else.
 
@@ -803,6 +816,8 @@ class DeleteShare(request.Request):
 class CreateUDF(request.Request):
     """Create a UDF."""
 
+    __slots__ = ('path', 'name', 'volume_id', 'node_id')
+
     def __init__(self, protocol, path, name):
         """Create a UDF.
 
@@ -844,6 +859,7 @@ class ListVolumes(request.Request):
         - the user's root-root.
 
     """
+    __slots__ = ('volumes',)
 
     def __init__(self, protocol):
         """List volumes."""
@@ -880,6 +896,8 @@ class ListVolumes(request.Request):
 class DeleteVolume(request.Request):
     """Delete a volume."""
 
+    __slots__ = ('volume_id',)
+
     def __init__(self, protocol, volume_id):
         """Delete a volume.
 
@@ -912,6 +930,8 @@ class Unlink(request.Request):
     """
     # pylint: disable=C0111
 
+    __slots__ = ('share', 'node', 'new_generation')
+
     def __init__(self, protocol, share, node_id):
         """Request that node_id be unlinked
 
@@ -947,6 +967,9 @@ class Move(request.Request):
     @ivar new_generation: the generation that the volume is at now
     """
 
+    __slots__ = ('share', 'node_id', 'new_parent_id', 'new_name',
+                 'new_generation')
+
     def __init__(self, protocol, share, node_id, new_parent_id, new_name):
         """Create the move request
 
@@ -993,6 +1016,8 @@ class MultiQuery(object):
 
     """
 
+    __slots__ = ('queries', 'deferred')
+
     def __init__(self, protocol, items):
         """Create a multiquery.
 
@@ -1029,6 +1054,8 @@ class Query(request.Request):
 
     """
 
+    __slots__ = ('query_message', 'response', 'overflow')
+
     def __init__(self, protocol, items):
         """Generate a query message to send to the server.
 
@@ -1143,6 +1170,10 @@ class PutContent(request.Request):
     @ivar new_generation: the generation that the volume is at now
     """
 
+    __slots__ = ('share', 'node_id', 'previous_hash', 'hash', 'crc32', 'size',
+                 'size', 'deflated_size', 'fd', 'upload_id_cb', 'upload_id',
+                 'new_generation', 'max_payload_size', 'magic_hash')
+
     def __init__(self, protocol, share, node_id, previous_hash, new_hash,
                  crc32, size, deflated_size, fd, upload_id=None,
                  upload_id_cb=None, magic_hash=None):
@@ -1239,6 +1270,8 @@ class MakeObject(request.Request):
 
     """
 
+    __slots__ = ('share', 'parent_id', 'name')
+
     def __init__(self, protocol, share, parent_id, name):
         """Create a node.
 
@@ -1324,15 +1357,19 @@ class Authenticate(request.Request):
     @ivar session_id: the session id with the server.
     """
 
-    def __init__(self, protocol, auth_parameters):
+    __slots__ = ('auth_parameters', 'session_id', 'metadata')
+
+    def __init__(self, protocol, auth_parameters, metadata=None):
         """Create an authentication request.
 
         @param protocol: the request handler
         @param auth_parameters: a dictionary of authentication parameters.
+        @param metadata: a dictionary of extra info
 
         """
         request.Request.__init__(self, protocol)
         self.auth_parameters = auth_parameters
+        self.metadata = metadata
         self.session_id = None
 
     def _start(self):
@@ -1343,6 +1380,11 @@ class Authenticate(request.Request):
             param = message.auth_parameters.add()
             param.name = key
             param.value = value
+        if self.metadata:
+            for key, value in self.metadata.items():
+                param = message.metadata.add()
+                param.key = key
+                param.value = value
         self.sendMessage(message)
 
     def processMessage(self, message):
@@ -1357,6 +1399,9 @@ class Authenticate(request.Request):
 class QuerySetCaps(request.Request):
     """Query or Set the server to use capabilities."""
 
+    __slots__ = ('caps', 'accepted', 'redirect_hostname', 'redirect_port',
+                 'redirect_srvrecord', 'set_mode')
+
     def __init__(self, protocol, caps, set_mode=False):
         """Generate a query_caps or set_caps message to send to the server.
 
@@ -1403,6 +1448,8 @@ class QuerySetCaps(request.Request):
 class FreeSpaceInquiry(request.Request):
     """Query available space."""
 
+    __slots__ = ('share_id', 'free_bytes')
+
     def __init__(self, protocol, share_id):
         """Initialize the request."""
         request.Request.__init__(self, protocol)
@@ -1430,6 +1477,8 @@ class FreeSpaceInquiry(request.Request):
 class AccountInquiry(request.Request):
     """Query account information."""
 
+    __slots__ = ('purchased_bytes',)
+
     def _start(self):
         """Send the FREE_SPACE_INQUIRY message to the server."""
         # pylint: disable=W0201
@@ -1491,6 +1540,10 @@ class GetDelta(request.Request):
         self.free_bytes = None
         self.generation = None
 
+    __slots__ = ('share_id', 'from_generation', 'callback', 'delta_message',
+                 'response', 'end_generation', 'full', 'free_bytes',
+                 'generation')
+
     def _start(self):
         """Send GET_DELTA."""
         self.sendMessage(self.delta_message)
