@@ -23,17 +23,23 @@ from OpenSSL import SSL
 from twisted.internet import ssl
 
 if sys.platform == "win32":
+    # diable pylint warning, as it may be the wrong platform
+    # pylint: disable=F0401
     import _winreg
-    
+
     # First open the registry hive
     hive = _winreg.ConnectRegistry(None, _winreg.HKEY_LOCAL_MACHINE)
-    # Then open the registry key where Windows stores the Shell Folder locations
-    key = _winreg.OpenKey(hive, "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders")
+    # Open the registry key where Windows stores the Shell Folder locations
+    key = _winreg.OpenKey(hive, str(
+            "Software\\Microsoft\\Windows\\CurrentVersion"
+            "\\Explorer\\Shell Folders"))
     for i in range(0, _winreg.QueryInfoKey(key)[1]):
         name, value, val_type = _winreg.EnumValue(key, i)
-        # Common AppData will always be present unless the user played with regedit
+        # Common AppData will always be present unless the user
+        # played with regedit
         if name == "Common AppData":
-            ssl_cert_location = os.path.join(value, "ubuntuone-storageprotocol")
+            ssl_cert_location = os.path.join(value,
+                                             "ubuntuone-storageprotocol")
             break
 else:
     ssl_cert_location = '/etc/ssl/certs'
