@@ -4,13 +4,13 @@
 #
 # Copyright 2009 Canonical Ltd.
 #
-# This program is free software: you can redistribute it and/or modify it 
+# This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License version 3,
 # as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU Affero General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
@@ -21,18 +21,17 @@ Standard routines for working with directory content.
 """
 
 import re
-# DIRECTORY, FILE, and SYMLINK are for re-export
-# pylint: disable-msg=W0611
-from ubuntuone.storageprotocol.dircontent_pb2 import \
-    DirectoryContent, DIRECTORY, FILE, SYMLINK
+from ubuntuone.storageprotocol.dircontent_pb2 import DirectoryContent
 
 ILLEGAL_FILENAMES = [u".", u".."]
 ILLEGAL_FILENAME_CHARS_RE_SOURCE = r'[\000/]'
 ILLEGAL_FILENAME_CHARS_RE = re.compile(ILLEGAL_FILENAME_CHARS_RE_SOURCE)
 
+
 class InvalidFilename(Exception):
     """Raised when a filename is invalid."""
 
+
 def validate_filename(filename):
     """Validates a filename for use with the storage service; raises
     InvalidFilename if the filename is invalid."""
@@ -43,6 +42,7 @@ def validate_filename(filename):
     if ILLEGAL_FILENAME_CHARS_RE.search(filename) is not None:
         raise InvalidFilename(u"%s contains illegal characters" % (filename,))
 
+
 def normalize_filename(filename):
     """Takes a unicode filename and returns the normalized form,
     raising InvalidFilename if the filename is invalid for use with
@@ -50,6 +50,7 @@ def normalize_filename(filename):
     validate_filename(filename)
     return filename
 
+
 def parse_dir_content(stream):
     """Unserializes directory content from a stream.
 
@@ -59,17 +60,19 @@ def parse_dir_content(stream):
     """
     raw_content = stream.read()
     unserialized_content = DirectoryContent()
-    # XXX: what exceptions can protobuf's parser raise?
+    # XXX what exceptions can protobuf's parser raise?
     unserialized_content.ParseFromString(raw_content)
 
     for entry in unserialized_content.entries:
         yield DirEntry(name=entry.name, node_type=entry.node_type,
                        uuid=entry.node)
 
+
 def by_utf8_name(entry_a, entry_b):
     """Compares two entries by the UTF-8 form of their names."""
     return cmp(entry_a.utf8_name, entry_b.utf8_name)
 
+
 def write_dir_content(entries, stream):
     """Takes a sequence of DirEntry objects, sorts them, and writes
     the corresponding serialized directory content to the given stream.
@@ -82,6 +85,7 @@ def write_dir_content(entries, stream):
     for chunk in yield_presorted_dir_content(sorted_entries):
         stream.write(chunk)
 
+
 def yield_presorted_dir_content(sorted_entries):
     """Takes a presorted sequence of DirEntry objects and yields each
     chunks of serialized content.
