@@ -282,6 +282,9 @@ class Request(object):
     """
     implements(IPushProducer)
 
+    __slots__ = ('protocol', 'id', 'deferred', 'producer', 'started',
+                 'finished', 'cancelled', 'producing')
+
     def __init__(self, protocol):
         """created a request.
 
@@ -449,6 +452,9 @@ class RequestResponse(Request):
 
     @ivar source_message: the message the generated this request.
     """
+
+    __slots__ = ('source_message',)
+
     # pylint: disable=W0223
     def __init__(self, protocol, message):
         """Create a request response.
@@ -470,9 +476,13 @@ class Ping(Request):
 
     @ivar rtt: will contain the round trip time when completed.
     """
+
+    __slots__ = ('_start_time', 'rtt')
+
     def _start(self):
         """start the request sending a ping message."""
         # pylint: disable=W0201
+        self.rtt = 0
         self._start_time = time.time()
         message = protocol_pb2.Message()
         message.id = self.id
